==> liquid_swipe-1.2.0.tar.gz: lib/Animation_Gesture/page_reveal.dart <==
import 'package:flutter/material.dart';
import 'package:liquid_swipe/Clippers/CircularWave.dart';
import 'package:liquid_swipe/Constants/Helpers.dart';

import '../Clippers/WaveLayer.dart';

/// This class reveals the next page in the liquid wave form.

class PageReveal extends StatelessWidget {
  final double revealPercent;
  final Widget child;
  final SlideDirection slideDirection;
  final double iconPosition;
  final WaveType waveType;

  //Constructor
  PageReveal({this.revealPercent,
    this.child,
    this.slideDirection,
    this.iconPosition,
    this.waveType });

  @override
  Widget build(BuildContext context) {
    //ClipPath clips our Container (page) with clipper based on path..
    switch (waveType) {
      case WaveType.liquidReveal:
        return ClipPath(
          clipper: WaveLayer(
              revealPercent: slideDirection == SlideDirection.leftToRight
                  ? 1.0 - revealPercent
                  : revealPercent,
              slideDirection: slideDirection,
              iconPosition: iconPosition),
          child: child,
        );
        break;
      case WaveType.circularReveal:
        return ClipPath(
          clipper: CircularWave(iconPosition,
              revealPercent: slideDirection == SlideDirection.leftToRight
                  ? 1.0 - revealPercent
                  : revealPercent),
          child: child,
        );
        break;
      default:
        return ClipPath(
          clipper: WaveLayer(
              revealPercent: slideDirection == SlideDirection.leftToRight
                  ? 1.0 - revealPercent
                  : revealPercent,
              slideDirection: slideDirection,
              iconPosition: iconPosition),
          child: child,
        );
        break;
    }
  }
}

==> liquid_swipe-1.3.0.tar.gz: lib/Animation_Gesture/page_reveal.dart <==
import 'package:flutter/material.dart';
import 'package:liquid_swipe/Clippers/CircularWave.dart';
import 'package:liquid_swipe/Constants/Helpers.dart';

import '../Clippers/WaveLayer.dart';

/// This class reveals the next page in the liquid wave form.

class PageReveal extends StatelessWidget {
  final double revealPercent;
  final Widget child;
  final SlideDirection slideDirection;
  final double iconPosition;
  final WaveType waveType;
  final double vertReveal;

  //Constructor
  PageReveal({this.revealPercent,
    this.child,
    this.slideDirection,
    this.iconPosition,
    this.waveType, this.vertReveal });

  @override
  Widget build(BuildContext context) {
    //ClipPath clips our Container (page) with clipper based on path..
    switch (waveType) {
      case WaveType.liquidReveal:
        return ClipPath(
          clipper: WaveLayer(
              revealPercent: slideDirection == SlideDirection.leftToRight
                  ? 1.0 - revealPercent
                  : revealPercent,
              slideDirection: slideDirection,
              iconPosition: iconPosition,
              verReveal: vertReveal),
          child: child,
        );
        break;
      case WaveType.circularReveal:
        return ClipPath(
          clipper: CircularWave(iconPosition,
              slideDirection == SlideDirection.leftToRight
                  ? 1.0 - revealPercent
                  : revealPercent, vertReveal),

          child: child,
        );
        break;
      default:
        return ClipPath(
          clipper: WaveLayer(
              revealPercent: slideDirection == SlideDirection.leftToRight
                  ? 1.0 - revealPercent
                  : revealPercent,
              slideDirection: slideDirection,
              iconPosition: iconPosition,
              verReveal: vertReveal),
          child: child,
        );
        break;
    }
  }
}
